# snowday

Tools for turning [Snowflake](https://www.snowflake.com/) into a Snow Day ❄️.


![Snowday](snowday.png)


### Installation

```
pip install snowday
```


### Usage



### License

Snowday is licensed under GPLv3.0.
